---
title: <span class="badge object-type-scalar"></span> CountsPerMinute
---
# <span class="badge object-type-scalar"></span> CountsPerMinute

Throughput: counts/min (cpm)

## Definition

```python
# Throughput: counts/min (cpm)
CountsPerMinute: typing.Literal["cpm"] = "cpm"
```
